==> h5p-7.x-1.18.tar.gz: h5p/modules/h5peditor/h5peditor/language/en.js <==
H5PEditor.language.core = {
  missingTranslation: '[Missing translation :key]',
  loading: 'Loading :type, please wait...',
  selectLibrary: 'Select the library you wish to use for your content.',
  unknownFieldPath: 'Unable to find ":path".',
  notImageField: '":path" is not an image.',
  notImageOrDimensionsField: '":path" is not an image or dimensions field.',
  requiredProperty: 'The :property is required and must have a value.',
  onlyNumbers: 'The :property value can only contain numbers.',
  exceedsMax: 'The :property value exceeds the maximum of :max.',
  belowMin: 'The :property value is below the minimum of :min.',
  outOfStep: 'The :property value can only be changed in steps of :step.',
  addFile: 'Add file',
  removeFile: 'Remove file',
  confirmRemoval: 'Are you sure you wish to remove this :type?',
  removeImage: 'Remove image',
  confirmImageRemoval: 'This will remove your image. Are you sure you wish to proceed?',
  changeFile: 'Change file',
  changeLibrary: 'Change content type?',
  semanticsError: 'Semantics error: :error',
  missingProperty: 'Field :index is missing its :property property.',
  expandCollapse: 'Expand/Collapse',
  addEntity: 'Add :entity',
  tooLong: 'Field value is too long, should contain :max letters or less.',
  invalidFormat: 'Field value contains an invalid format or characters that are forbidden.',
  confirmChangeLibrary: 'By doing this you will lose all work done with the current content type. Are you sure you wish to change content type?',
  moreLibraries: 'Look for <a href="http://h5p.org/content-types-and-applications" target="_blank">more content types</a> on h5p.org',
  commonFields: 'Settings and texts',
  commonFieldsDescription: 'Here you can edit settings or translate texts used in this content.',
  uploading: 'Uploading, please wait...',
  noFollow: 'Cannot follow field ":path".',
  editCopyright: 'Edit copyright',
  close: 'Close',
  tutorialAvailable: 'Tutorial available',
  editMode: 'Editing mode',
  listLabel: 'List',
  uploadError: 'File Upload Error',
  fileToLarge: 'The file you are trying to upload might be too large.',
  unknownFileUploadError: 'Unknown file upload error',
  noSemantics: 'Error, could not load the content type form.',
  editImage: 'Edit image',
  saveLabel: 'Save',
  cancelLabel: 'Cancel',
  resetToOriginalLabel: 'Reset to original',
  loadingImageEditor: 'Loading image editor, please wait...',
  selectFiletoUpload: 'Select file to upload',
  or: 'or',
  enterAudioUrl: 'Enter audio source URL',
  enterVideoUrl: 'Enter video source URL or YouTube link',
  addVideoDescription: 'H5P supports all external video sources formatted as mp4, webm or ogv, like Vimeo Pro, and has support for YouTube links.',
  insert: 'Insert',
  cancel: 'Cancel',
  height: 'height',
  width: 'width',
  textField: 'text field',
  numberField: 'number field'
};

==> h5p-7.x-1.19.tar.gz: h5p/modules/h5peditor/h5peditor/language/en.js <==
H5PEditor.language.core = {
  missingTranslation: '[Missing translation :key]',
  loading: 'Loading :type, please wait...',
  selectLibrary: 'Select the library you wish to use for your content.',
  unknownFieldPath: 'Unable to find ":path".',
  notImageField: '":path" is not an image.',
  notImageOrDimensionsField: '":path" is not an image or dimensions field.',
  requiredProperty: 'The :property is required and must have a value.',
  onlyNumbers: 'The :property value can only contain numbers.',
  exceedsMax: 'The :property value exceeds the maximum of :max.',
  belowMin: 'The :property value is below the minimum of :min.',
  outOfStep: 'The :property value can only be changed in steps of :step.',
  addFile: 'Add file',
  removeFile: 'Remove file',
  confirmRemoval: 'Are you sure you wish to remove this :type?',
  removeImage: 'Remove image',
  confirmImageRemoval: 'This will remove your image. Are you sure you wish to proceed?',
  changeFile: 'Change file',
  changeLibrary: 'Change content type?',
  semanticsError: 'Semantics error: :error',
  missingProperty: 'Field :index is missing its :property property.',
  expandCollapse: 'Expand/Collapse',
  addEntity: 'Add :entity',
  tooLong: 'Field value is too long, should contain :max letters or less.',
  invalidFormat: 'Field value contains an invalid format or characters that are forbidden.',
  confirmChangeLibrary: 'By doing this you will lose all work done with the current content type. Are you sure you wish to change content type?',
  moreLibraries: 'Look for <a href="http://h5p.org/content-types-and-applications" target="_blank">more content types</a> on h5p.org',
  commonFields: 'Text overrides and translations',
  commonFieldsDescription: 'Here you can edit settings or translate texts used in this content.',
  uploading: 'Uploading, please wait...',
  noFollow: 'Cannot follow field ":path".',
  editCopyright: 'Edit copyright',
  close: 'Close',
  tutorialAvailable: 'Tutorial available',
  editMode: 'Editing mode',
  listLabel: 'List',
  uploadError: 'File Upload Error',
  fileToLarge: 'The file you are trying to upload might be too large.',
  unknownFileUploadError: 'Unknown file upload error',
  noSemantics: 'Error, could not load the content type form.',
  editImage: 'Edit image',
  saveLabel: 'Save',
  cancelLabel: 'Cancel',
  resetToOriginalLabel: 'Reset to original',
  loadingImageEditor: 'Loading image editor, please wait...',
  selectFiletoUpload: 'Select file to upload',
  or: 'or',
  enterAudioUrl: 'Enter audio source URL',
  enterVideoUrl: 'Enter video source URL or YouTube link',
  addVideoDescription: 'H5P supports all external video sources formatted as mp4, webm or ogv, like Vimeo Pro, and has support for YouTube links.',
  insert: 'Insert',
  cancel: 'Cancel',
  height: 'height',
  width: 'width',
  textField: 'text field',
  numberField: 'number field'
};
